@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11646 2019-07-01 01:31:33Z Andy $
+# $Id: views.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-07-01 09:31:33 +0800 (週一, 01 七月 2019) $
-# $Revision: 11646 $
+# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 import re
 import time
@@ -26,7 +26,7 @@ from Iuppiter.extension.views import jsonpCallback
 from Iuppiter.Logging import createLogger
 
 from django.contrib.sites.models import Site
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.shortcuts import HttpResponse
 from django.utils.translation import ugettext as _
 from django.core.cache import cache
