@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,13 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django import forms
 from django.contrib import admin
 from django.utils.translation import gettext as _
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 from emencia.django.newsletter.models import Newsletter
 # #FIXME: Django forms dependencies issues, 
