@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10762 2018-02-02 07:47:39Z David $
+# $Id: __init__.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-02-02 15:47:39 +0800 (週五, 02 二月 2018) $
-# $Revision: 10762 $
+# $Author: Andy $
+# $Date: 2019-06-07 11:15:46 +0900 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Theophrastus.integration import views
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^statistics/display/(?P<groupId>\d+)/$',
         views.displayStatistics,
         name='Theophrastus.integration.views.displayStatistics'),
@@ -42,5 +42,5 @@ urlpatterns = patterns('',
     url(r'^tracking/historic/(?P<groupId>\d+)/$',
         views.getGroupHistory,
         name='Theophrastus.admin.integration.views.getGroupHistory'),
-)
+]
 
